parserFwk.pyparsing.ParseFatalException

Package parserFwk :: Module pyparsing :: Class ParseFatalException |
[frames | no frames]

## Class ParseFatalException

         Exception --+
                     |
    ParseBaseException --+
                         |
                        ParseFatalException

user-throwable exception thrown when inconsistent parse content is found; stops all parsing immediately

Method Summary
Inherited from `ParseBaseException`: `__init__`, `__getattr__`, `__repr__`, `__str__`, `markInputline` Inherited from `Exception`: `__getitem__`

Class Variable Summary
Inherited from `ParseBaseException`: `__slots__`

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net